#####################################################################
#                                                                   #
# /user_devices/FastComtecMCS8A/labscript_devices.py                #
#                                                                   #
# Feb. 2024, Leonard Group                                          #
#                                                                   #
#                                                                   #
#####################################################################
from labscript import TriggerableDevice, Trigger, set_passed_properties, config

class MCS8A(TriggerableDevice):
    description = 'MCS8A'

    @set_passed_properties(
        property_names={"connection_table_properties":["config_path"]}
    )
    def __init__(self, name, parent_device, connection, SPCM_gate_parent=None, SPCM_gate_connection=None, config_path="MCS8A_default_config.SET",  **kwargs):
        super().__init__(name, parent_device, connection, **kwargs)
        self.BLACS_connection = "SPCM MCS8A"
        self.config_path = config_path
        self.labels = {}

        if SPCM_gate_parent is not None:
            self.SPCM_gate = Trigger(
                f"{name}_SPCM_gate", SPCM_gate_parent, SPCM_gate_connection, trigger_edge_type="falling"
            )

    def acquire(self, t, duration, trigger_duration=None, label=""):
        if trigger_duration is None:
            trigger_duration = duration
        self.labels[t] = label
        self.trigger(t,trigger_duration)
        if hasattr(self,"SPCM_gate"):
            self.SPCM_gate.trigger(t,duration)

    def generate_code(self, hdf5_file):
        group = hdf5_file.create_group(f"devices/{self.name}")
        labels_group = group.create_group("labels")
        for t,label in self.labels.items():
            labels_group.attrs[str(t)] = label
        
        group.attrs["n_trigger"] = len(self.trigger_device.triggerings)
        durations = [triggering[1] for triggering in self.trigger_device.triggerings]
        group.create_dataset("durations", compression = config.compression, data = durations)

        super().generate_code(hdf5_file)
       


